from ..mongo import Mongo

class MongoTeacher(Mongo):
    def __init__(self,host, port, db):
        super(MongoTeacher,self).__init__(host, port, db)


    def insert_vote(self, collection, news_id, user_id, vote):
        #controllare se esiste un doc per la news
        selected_collection = self.connection[collection]
        result = selected_collection.find_one({"_id":news_id})
        tot = 1
        if result:
            #aggiorna il voto per l'utente
            #aggiungi +1 a tot
            tot = result["tot"] + 1
            updated = selected_collection.update_one({'_id':int(news_id)}, {"$set":{"tot":int(tot), "register." + str(user_id): int(vote)}}, upsert=False)
        else:
            #inserisci
            tmp = {
                "_id": int(news_id),
                "tot": tot,
                "register":{str(user_id):vote}
            }
            insert = selected_collection.insert_one(tmp)

        return tot

    def insert_stage(self, collection, category_name, news_id):
        selected_collection = self.connection[collection]
        result = selected_collection.find_one({})
        if result:
            if category_name in result:
                selected_collection.update_one({}, {"$addToSet":{category_name: int(news_id)}})
            else:
                selected_collection.update_one({}, {"$set": {category_name: [int(news_id)]}})
        else:
            tmp = {
                category_name: [int(news_id)]
            }
            selected_collection.insert_one(tmp)




from fluent import sender
from fluent import event
import datetime

sender.setup('fluentd.test', host='localhost', port=24224)



class Logger:
    def __init__(self,host,port,name):
        self.host = host
        self.port = port
        self.name = name
        sender.setup('fluentd.justpith', host=self.host, port=self.port)

    def log(self,message,source):
        time  = datetime.datetime.now().strftime('[%d-%m-%Y %H:%M:%S]')
        output = {
            "time": time,
            "output": message,
            "source": source
        }
        event.Event(self.name, output)


from ..mongo import Mongo

class MongoController(Mongo):
    def __init__(self,host, port, db):
        super(MongoController,self).__init__(host, port, db)
        self.collection = "Controller"

    def insert_job(self,job):
        selected_collection = self.connection[self.collection]
        selected_collection.insert_one(job)

    def insert_model_into_job(self, job_id, model_id, type):
        selected_collection = self.connection[self.collection]
        if type == "text":
            result = selected_collection.update_one({"_id":job_id},{"$set":{"id_text": str(model_id)}})
        elif type == "matrix":
            result = selected_collection.update_one({"_id":job_id}, {"$set": {"id_matrix": str(model_id)}})

    def get_job(self, job_id):
        selected_collection = self.connection[self.collection]
        result = selected_collection.find_one({"_id": job_id} )
        return result

    def deactiva_job(self, job_id):
        pass

    def active_job(self, job_id):
        selected_collection = self.connection[self.collection]
        result = selected_collection.update_one({"_id": job_id}, {"$set": {"active": 1}})